datasets
********

Busan Beach data
================
.. automodule:: ai4water.datasets.busan_beach
   :show-inheritance:

Datasets
========
.. autoclass:: ai4water.datasets.datasets.Datasets
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

MtropicsLaos
=============
.. autoclass:: ai4water.datasets.datasets.MtropicsLaos
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

Camels
======
.. autoclass:: ai4water.datasets.camels.Camels
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

CAMELS_AUS
==========
.. autoclass:: ai4water.datasets.camels.CAMELS_AUS
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

LamaH
======
.. autoclass:: ai4water.datasets.camels.LamaH
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

CAMELS_GB
==========
.. autoclass:: ai4water.datasets.camels.CAMELS_GB
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

CAMELS_BR
==========
.. autoclass:: ai4water.datasets.camels.CAMELS_BR
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

CAMELS_US
=========
.. autoclass:: ai4water.datasets.camels.CAMELS_US
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

CAMELS_CL
=========
.. autoclass:: ai4water.datasets.camels.CAMELS_CL
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

HYSETS
======
.. autoclass:: ai4water.datasets.camels.HYSETS
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

HYPE
====
.. autoclass:: ai4water.datasets.camels.HYPE
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

Weisssee
========
.. autoclass:: ai4water.datasets.datasets.Weisssee
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

WeatherJena
===========
.. autoclass:: ai4water.datasets.datasets.WeatherJena
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

SWECanada
=========
.. autoclass:: ai4water.datasets.datasets.SWECanada
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
